@@ -14,65 +14,122 @@ def stats(zones: xr.DataArray,
           values: xr.DataArray,
           stat_funcs=['mean', 'max', 'min', 'std', 'var', 'count']):
     """
-    Calculate summary statistics for each zone defined by a zone dataset,
-    based on values aggregate.
+    Calculate summary statistics for each zone defined by a zone
+    dataset, based on values aggregate.
 
-    A single output value is computed for every zone in the input zone dataset.
+    A single output value is computed for every zone in the input zone
+    dataset.
 
-    Parameters:
+    Parameters
     ----------
-    zones: xarray.DataArray,
+    zones : xr.DataArray
         zones.values is a 2d array of integers.
         A zone is all the cells in a raster that have the same value,
         whether or not they are contiguous. The input zone layer defines
         the shape, values, and locations of the zones. An integer field
         in the zone input is specified to define the zones.
-
-    values: xarray.DataArray,
+    values : xr.DataArray
         values.values is a 2d array of integers or floats.
-        The input value raster contains the input values used in calculating
-        the output statistic for each zone.
+        The input value raster contains the input values used in
+        calculating the output statistic for each zone.
+    stat_funcs : list of string or dict, default=['mean', 'max', 'min',
+        'std', 'var', 'count'])
+        Which statistics to calculate for each zone. If a list, possible
+        choices are subsets of ['mean', 'max', 'min', 'std', 'var',
+        'count']. In the dictionary case, all of its values must be
+        callable. Function takes only one argument that is the zone
+        values. The key become the column name in the output DataFrame.
 
-    stat_funcs: list of strings or dictionary<stat_name: func(zone_values)>.
-                (default = ['mean', 'max', 'min', 'std', 'var', 'count'])
-        Which statistics to calculate for each zone.
-        If a list, possible choices are subsets of
-        ['mean', 'max', 'min', 'std', 'var', 'count']
-        In the dictionary case, all of its values must be callable.
-        Function takes only one argument that is the zone values.
-        The key become the column name in the output DataFrame.
+    Returns
+    -------
+    stats_df : pandas.DataFrame
+        A pandas DataFrame where each column is a statistic and each
+        row is a zone with zone id.
 
-    Returns:
-    ----------
-    stats_df: pandas.DataFrame
-        A pandas DataFrame where each column is a statistic and each row
-        is a zone with zone id.
-
-    Examples:
+    Examples
     --------
-    >>> zones_val = np.array([[1, 1, 0, 2],
-    >>>                      [0, 2, 1, 2]])
-    >>> zones = xarray.DataArray(zones_val)
-    >>> values_val = np.array([[2, -1, 5, 3],
-    >>>                       [3, np.nan, 20, 10]])
-    >>> values = xarray.DataArray(values_val)
+    .. plot::
+       :include-source:
 
-    # default setting
-    >>> df = stats(zones, values)
-    >>> df
-        mean	max 	min 	std     	var
-    1	7.0 	20.0	-1.0	9.273618	86.00
-    2	6.5	    10.0   	3.0	    3.500000	12.25
+        import datashader as ds
+        import matplotlib.pyplot as plt
+        from xrspatial import generate_terrain
+        from xrspatial.classify import equal_interval
+        from xrspatial.zonal import stats
 
-    # custom stat
-    >>> custom_stats ={'sum': lambda val: val.sum()}
-    >>> df = stats(zones, values, stat_funcs=custom_stats)
-    >>> df
-        sum
-    1	21.0
-    2	13.0
+        # Create Canvas
+        W = 500
+        H = 300
+        cvs = ds.Canvas(plot_width = W,
+                        plot_height = H,
+                        x_range = (-20e6, 20e6),
+                        y_range = (-20e6, 20e6))
+
+
+        # Generate Values
+        terrain_agg = generate_terrain(canvas = cvs)
+
+        # Edit Attributes
+        terrain_agg = terrain_agg.assign_attrs(
+            {
+                'Description': 'Example Terrain',
+                'units': 'km',
+                'Max Elevation': '4000',
+            }
+        )
+
+        terrain_agg = terrain_agg.rename({'x': 'lon', 'y': 'lat'})
+        terrain_agg = terrain_agg.rename('Elevation')
+
+        # Create Zones
+        equal_interval_agg = equal_interval(
+            agg = terrain_agg,
+            name = 'Elevation',
+        )
+        equal_interval_agg = equal_interval_agg.astype('int')
+
+        # Edit Attributes
+        equal_interval_agg = equal_interval_agg.assign_attrs(
+            {
+                'Description': 'Example Equal Interval',
+            }
+        )
+
+        # Plot Terrain (Values)
+        terrain_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Terrain (Values)")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+        # Plot Equal Interval (Zones)
+        equal_interval_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Equal Interval (Zones)")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+    .. sourcecode:: python
+
+        >>> # Calculate Stats
+        >>> stats_agg = stats(zones = equal_interval_agg, values = terrain_agg)
+        >>> print(stats_agg)
+                  mean          max          min         std           var    count # noqa
+        1  1346.099206  1599.980772  1200.014238  107.647012  11587.879265  52698.0 # noqa
+        2  1867.613738  2399.949943  1600.049783  207.072933  42879.199507  22987.0 # noqa
+        3  2716.967940  3199.499889  2400.079093  215.475764  46429.804756   4926.0 # noqa
+        4  3491.072129  4000.000000  3200.057209  182.752194  33398.364467   1373.0 # noqa
+
+        >>> # Custom Stats
+        >>> custom_stats ={'sum': lambda val: val.sum()}
+        >>> custom_stats_agg = stats(zones = equal_interval_agg,
+                                     values = terrain_agg,
+                                     stat_funcs=custom_stats)
+        >>> print(custom_stats_agg)
+                    sum
+        1  7.093674e+07
+        2  4.293084e+07
+        3  1.338378e+07
+        4  4.793242e+06
     """
-
     if zones.shape != values.shape:
         raise ValueError(
             "`zones` and `values` must have same shape")
@@ -203,8 +260,8 @@ def crosstab(zones: xr.DataArray,
              layer: Optional[str] = None) -> pd.DataFrame:
     """
     Calculate cross-tabulated (categorical stats) areas
-    between two datasets: a zone dataset, a value dataset (a value raster).
-    Outputs a pandas DataFrame.
+    between two datasets: a zone dataset, a value dataset (a value
+    raster). Outputs a pandas DataFrame.
 
     Requires a DataArray with a single data dimension, here called the
     "values", indexed using 3D coordinates.
@@ -215,31 +272,124 @@ def crosstab(zones: xr.DataArray,
     2D-coordinate case if collapsed across the categories (e.g. if one
     did ``aggc.sum(dim='cat')`` for a categorical dimension ``cat``).
 
-    Parameters:
+    Parameters
     ----------
-    zones: xarray.DataArray,
+    zones : xr.DataArray
         zones.values is a 2d array of integers.
         A zone is all the cells in a raster that have the same value,
         whether or not they are contiguous. The input zone layer defines
         the shape, values, and locations of the zones. An integer field
         in the zone input is specified to define the zones.
-
-    values: xarray.DataArray,
+    values : xr.DataArray
         values.values is a 3d array of integers or floats.
-        The input value raster contains the input values used in calculating
-        the categorical statistic for each zone.
+        The input value raster contains the input values used in
+        calculating the categorical statistic for each zone.
+    layer: str, default=None
+        name of the layer inside the `values` DataArray for getting
+        the values.
 
-    layer: str, optional (default = None)
-        name of the layer inside the `values` DataArray for getting the values.
-
-    Returns:
-    ----------
-    crosstab_df: pandas.DataFrame
+    Returns
+    -------
+    crosstab_df : pandas.DataFrame
         A pandas DataFrame where each column is a categorical value
         and each row is a zone with zone id.
         Each entry presents the percentage of the category over the zone.
-    """
 
+    Examples
+    --------
+    .. plot::
+       :include-source:
+
+        import datashader as ds
+        import matplotlib.pyplot as plt
+        from xrspatial import generate_terrain
+        from xrspatial.classify import equal_interval
+        from xrspatial.zonal import crosstab
+
+        # Create Canvas
+        W = 500
+        H = 300
+        cvs = ds.Canvas(plot_width = W,
+                        plot_height = H,
+                        x_range = (-20e6, 20e6),
+                        y_range = (-20e6, 20e6))
+
+
+        # Generate Values
+        terrain_agg = generate_terrain(canvas = cvs)
+
+        # Edit Attributes
+        terrain_agg = terrain_agg.assign_attrs(
+            {
+                'Description': 'Example Terrain',
+                'units': 'km',
+                'Max Elevation': '4000',
+            }
+        )
+
+        terrain_agg = terrain_agg.rename({'x': 'lon', 'y': 'lat'})
+        terrain_agg = terrain_agg.rename('Elevation')
+
+        # Create Zones
+        equal_interval_agg = equal_interval(
+            agg = terrain_agg,
+            name = 'Elevation',
+        )
+        equal_interval_agg = equal_interval_agg.astype('int')
+
+        # Edit Attributes
+        equal_interval_agg = equal_interval_agg.assign_attrs(
+            {
+                'Description': 'Example Equal Interval',
+            }
+        )
+
+        # Plot Terrain (Values)
+        terrain_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Terrain (Values)")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+        # Plot Equal Interval (Zones)
+        equal_interval_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Equal Interval (Zones)")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+    .. sourcecode:: python
+
+        >>> # Calculate Crosstab
+        >>> crosstab_agg = crosstab(
+                zones=equal_interval_agg,
+                values=terrain_agg,
+            )
+        >>> print(crosstab_agg)
+           0.000000     1200.014238  1200.014864  1200.021077  1200.027001
+        1          0.0     0.000019     0.000019     0.000019     0.000019
+        2          0.0     0.000000     0.000000     0.000000     0.000000
+        3          0.0     0.000000     0.000000     0.000000     0.000000
+        4          0.0     0.000000     0.000000     0.000000     0.000000
+
+           1200.030954  1200.034319  1200.038300  1200.042588  1200.042805
+        1     0.000019     0.000019     0.000019     0.000019     0.000019
+        2     0.000000     0.000000     0.000000     0.000000     0.000000
+        3     0.000000     0.000000     0.000000     0.000000     0.000000
+        4     0.000000     0.000000     0.000000     0.000000     0.000000
+
+           3932.764078  3946.456024  3947.505026  3952.279254  3957.748147
+        1     0.000000     0.000000     0.000000     0.000000     0.000000
+        2     0.000000     0.000000     0.000000     0.000000     0.000000
+        3     0.000000     0.000000     0.000000     0.000000     0.000000
+        4     0.000728     0.000728     0.000728     0.000728     0.000728
+
+           3968.600152  3973.840684  3989.509344  3998.678232  4000.000000
+        1     0.000000     0.000000     0.000000     0.000000     0.000000
+        2     0.000000     0.000000     0.000000     0.000000     0.000000
+        3     0.000000     0.000000     0.000000     0.000000     0.000000
+        4     0.000728     0.000728     0.000728     0.000728     0.000728
+
+        [4 rows x 81984 columns]
+    """
     if not isinstance(zones, xr.DataArray):
         raise TypeError("zones must be instance of DataArray")
 
@@ -276,38 +426,35 @@ def apply(zones: xr.DataArray,
     Apply a function to the `values` agg within zones in `zones` agg.
     Change the agg content.
 
-    Parameters:
+    Parameters
     ----------
-    zones: xarray.DataArray,
-        - zones.values is a 2d array of integers.
-        - A zone is all the cells in a raster that have the same value,
-          whether or not they are contiguous. The input zone layer defines
-          the shape, values, and locations of the zones. An integer field
-          in the zone input is specified to define the zones.
-    agg: xarray.DataArray,
-        - agg.values is either a 2D or 3D array of integers or floats.
-        - The input value raster.
-    func: callable function to apply.
+    zones : xr.DataArray
+        zones.values is a 2d array of integers. A zone is all the cells
+        in a raster that have the same value, whether or not they are
+        contiguous. The input zone layer defines the shape, values, and
+        locations of the zones. An integer field in the zone input is
+        specified to define the zones.
+    agg : xr.DataArray
+        agg.values is either a 2D or 3D array of integers or floats.
+        The input value raster.
+    func : callable function to apply.
 
-    Returns:
-    ----------
-        None
-
-    Examples:
+    Examples
     --------
-    >>> zones_val = np.array([[1, 1, 0, 2],
-    >>>                       [0, 2, 1, 2]])
-    >>> zones = xarray.DataArray(zones_val)
-    >>> values_val = np.array([[2, -1, 5, 3],
-    >>>                   [3, np.nan, 20, 10]])
-    >>> agg = xarray.DataArray(values_val)
-    >>> func = lambda x: 0
-    >>> apply(zones, agg, func)
-    >>> agg
-    >>> array([[0, 0, 5, 0],
-    >>>        [3, 0, 0, 0]])
-    """
+    .. sourcecode:: python
 
+        >>> zones_val = np.array([[1, 1, 0, 2],
+        >>>                       [0, 2, 1, 2]])
+        >>> zones = xarray.DataArray(zones_val)
+        >>> values_val = np.array([[2, -1, 5, 3],
+        >>>                        [3, np.nan, 20, 10]])
+        >>> agg = xarray.DataArray(values_val)
+        >>> func = lambda x: 0
+        >>> apply(zones, agg, func)
+        >>> agg
+        array([[0, 0, 5, 0],
+               [3, 0, 0, 0]])
+    """
     if not isinstance(zones, xr.DataArray):
         raise TypeError("zones must be instance of DataArray")
 
@@ -356,6 +503,30 @@ def apply(zones: xr.DataArray,
 
 
 def get_full_extent(crs):
+    """
+    Returns the full extent of a map projection, available projections
+    are 'Mercator' and 'Geographic'.
+
+    Parameters
+    ----------
+    crs : str
+        Input projection.
+
+    Returns
+    -------
+    extent : tuple
+        Projection extent of form ((min_x, max_x), (min_y, max_y)).
+
+    Examples
+    --------
+    .. sourcecode:: python
+
+        >>> from xrspatial.zonal import get_full_extent
+
+        >>> extent = get_full_extent('Mercator')
+        >>> print(extent)
+        ((-20000000.0, 20000000.0), (-20000000.0, 20000000.0))
+    """
     Mercator = (-20e6, 20e6), (-20e6, 20e6)
     Geographic = (-180, 180), (-90, 90)
 
@@ -376,64 +547,72 @@ def suggest_zonal_canvas(smallest_area: Union[int, float],
                          min_pixels: int = 25) -> tuple:
     """
     Given a coordinate reference system (crs), a set of polygons with
-    corresponding x range and y range, calculate the height and width of canvas
-    so that the smallest polygon (polygon with smallest area) is rasterized
-    with at least min pixels.
+    corresponding x range and y range, calculate the height and width
+    of canvas so that the smallest polygon (polygon with smallest area)
+    is rasterized with at least min pixels.
 
-    Currently, we assume that the smallest polygon does not intersect others.
-    One should note that a polygon can have different shapes when it is
-    rasterized in canvases of different size. Thus, we cannot 100% guarantee
-    the actual number of pixels after rasterization. It is recommended to add
-    an additional of 5% to @min_pixels parameter.
+    Currently, we assume that the smallest polygon does not intersect
+    others. One should note that a polygon can have different shapes
+    when it is rasterized in canvases of different size. Thus, we cannot
+    100% guarantee the actual number of pixels after rasterization.
+    It is recommended to add an additional of 5% to @min_pixels parameter.
 
-    Parameters:
+    Parameters
     ----------
-    x_range: tuple or list of 2 numeric elements,
+    x_range : tuple or list of float or int
         The full x extent of the polygon GeoDataFrame.
-    y_range: tuple or list of 2 numeric elements,
+    y_range : tuple or list of float or int
         The full y extent of the polygon GeoDataFrame.
-    smallest_area: numeric (float, int)
+    smallest_area : float or int
         Area of the smallest polygon.
-    crs: str (default = 'Mercator)
+    crs : str, default='Mercator'
         Name of the coordinate reference system.
-    min_pixels: int (default = 25)
+    min_pixels : int, default=25
         Expected number of pixels of the polygon with smallest area
         when the whole dataframe is rasterized.
 
-    Returns:
-    ----------
-    height, width: int, int
-        height and width of the canvas in pixel space
+    Returns
+    -------
+    height, width: int
+        Height and width of the canvas in pixel space.
 
-    Examples:
-    ----------
-    Imports
-    >>> from spatialpandas import GeoDataFrame
-    >>> import geopandas as gpd
-    >>> import datashader as ds
+    Examples
+    --------
+    .. sourcecode:: python
 
-    >>> df = gpd.read_file(gpd.datasets.get_path('naturalearth_lowres'))
-    >>> df = df.to_crs("EPSG:3857")
-    >>> df = df[df.continent != 'Antarctica']
-    >>> df['id'] = [i for i in range(len(df.index))]
-    >>> xmin, ymin, xmax, ymax = (df.bounds.minx.min(), df.bounds.miny.min(),
-...                               df.bounds.maxx.max(), df.bounds.maxy.max())
-    >>> x_range = (xmin, xmax)
-    >>> y_range = (ymin, ymax)
-    >>> smallest_area = df.area.min()
-    >>> min_pixels = 20
-    >>> height, width = suggest_zonal_canvas(x_range=x_range, y_range=y_range,
-...                                          smallest_area=smallest_area,
-...                                          crs='Mercator',
-...                                          min_pixels=min_pixels)
-    >>> cvs = ds.Canvas(x_range=x_range, y_range=y_range,
-...                     plot_height=height, plot_width=width)
-    >>> spatial_df = GeoDataFrame(df, geometry='geometry')
-    >>> agg = cvs.polygons(spatial_df, 'geometry', agg=ds.max('id'))
-    >>> min_poly_id = df.area.argmin()
-    >>> actual_min_pixels = len(np.where(agg.data==min_poly_id)[0])
+        >>> # Imports
+        >>> from spatialpandas import GeoDataFrame
+        >>> import geopandas as gpd
+        >>> import datashader as ds
+
+        >>> df = gpd.read_file(gpd.datasets.get_path('naturalearth_lowres'))
+        >>> df = df.to_crs("EPSG:3857")
+        >>> df = df[df.continent != 'Antarctica']
+        >>> df['id'] = [i for i in range(len(df.index))]
+        >>> xmin, ymin, xmax, ymax = (
+                df.bounds.minx.min(),
+                df.bounds.miny.min(),
+                df.bounds.maxx.max(),
+                df.bounds.maxy.max(),
+            )
+        >>> x_range = (xmin, xmax)
+        >>> y_range = (ymin, ymax)
+        >>> smallest_area = df.area.min()
+        >>> min_pixels = 20
+        >>> height, width = suggest_zonal_canvas(
+                x_range=x_range,
+                y_range=y_range,
+                smallest_area=smallest_area,
+                crs='Mercator',
+                min_pixels=min_pixels,
+            )
+        >>> cvs = ds.Canvas(x_range=x_range, y_range=y_range,
+        >>>             plot_height=height, plot_width=width)
+        >>> spatial_df = GeoDataFrame(df, geometry='geometry')
+        >>> agg = cvs.polygons(spatial_df, 'geometry', agg=ds.max('id'))
+        >>> min_poly_id = df.area.argmin()
+        >>> actual_min_pixels = len(np.where(agg.data==min_poly_id)[0])
     """
-
     full_xrange, full_yrange = get_full_extent(crs)
     xmin, xmax = full_xrange
     ymin, ymax = full_yrange
@@ -610,24 +789,106 @@ def regions(raster: xr.DataArray,
     Connectivity can be based on either 4 or 8-pixel neighborhoods.
     Output raster contain a unique int for each connected region.
 
-    Parameters:
+    Parameters
     ----------
-    raster : xarray.DataArray
-    connections : int (default = 4)
-        4 or 8 pixel-based connectivity
-    name: str (default = 'regions)
-        output xr.DataArray.name property
+    raster : xr.DataArray
+    connections : int, default=4
+        4 or 8 pixel-based connectivity.
+    name: str, default='regions'
+        output xr.DataArray.name property.
 
-    Returns:
-    ----------
-    xarray.DataArray
+    Returns
+    -------
+    regions_agg : xarray.DataArray
 
-    Notes:
+    References
     ----------
-    Area Numbering implementing based on:
-        - Hengl, T, Spatial Analyst, http://spatial-analyst.net/ILWIS/htm/ilwisapp/areanumbering_algorithm.htm, Accessed Apr. 22, 2021. # noqa
+        - Tomislav Hengl: http://spatial-analyst.net/ILWIS/htm/ilwisapp/areanumbering_algorithm.htm # noqa
+
+    Examples
+    --------
+    .. plot::
+       :include-source:
+
+        import datashader as ds
+        import matplotlib.pyplot as plt
+        from xrspatial import generate_terrain
+        from xrspatial.zonal import regions
+
+        # Create Canvas
+        W = 500
+        H = 300
+        cvs = ds.Canvas(plot_width = W,
+                        plot_height = H,
+                        x_range = (-20e6, 20e6),
+                        y_range = (-20e6, 20e6))
+
+
+        # Generate Values
+        terrain_agg = generate_terrain(canvas = cvs)
+
+        # Edit Attributes
+        terrain_agg = terrain_agg.assign_attrs(
+            {
+                'Description': 'Example Terrain',
+                'units': 'km',
+                'Max Elevation': '4000',
+            }
+        )
+        
+        terrain_agg = terrain_agg.rename({'x': 'lon', 'y': 'lat'})
+        terrain_agg = terrain_agg.rename('Elevation')
+
+        # Create Regions
+        regions_agg = regions(terrain_agg)
+
+        # Edit Attributes
+        regions_agg = regions_agg.assign_attrs({'Description': 'Example Regions',
+                                                 'units': ''})
+        regions_agg = regions_agg.rename('Region Value')
+
+        # Plot Terrain (Values)
+        terrain_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Terrain (Values)")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+        # Plot Regions
+        regions_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Regions")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+    .. sourcecode:: python
+
+        >>> print(terrain_agg[200:203, 200:202])
+        <xarray.DataArray 'Elevation' (lat: 3, lon: 2)>
+        array([[1264.02249454, 1261.94748873],
+               [1285.37061171, 1282.48046696],
+               [1306.02305679, 1303.40657515]])
+        Coordinates:
+          * lon      (lon) float64 -3.96e+06 -3.88e+06
+          * lat      (lat) float64 6.733e+06 6.867e+06 7e+06
+        Attributes:
+            res:            1
+            Description:    Example Terrain
+            units:          km
+            Max Elevation:  4000
+
+        >>> print(regions_agg[200:203, 200:202])
+        <xarray.DataArray 'Region Value' (lat: 3, lon: 2)>
+        array([[39557., 39558.],
+               [39943., 39944.],
+               [40327., 40328.]])
+        Coordinates:
+          * lon      (lon) float64 -3.96e+06 -3.88e+06
+          * lat      (lat) float64 6.733e+06 6.867e+06 7e+06
+        Attributes:
+            res:            1
+            Description:    Example Regions
+            units:
+            Max Elevation:  4000
     """
-
     if neighborhood not in (4, 8):
         raise ValueError('`neighborhood` value must be either 4 or 8)')
 
@@ -733,26 +994,103 @@ def trim(raster: xr.DataArray,
          values: Union[list, tuple] = (np.nan,),
          name: str = 'trim') -> xr.DataArray:
     """
-    Trim scans from the edges and eliminates rows / cols
-    which only contain the values supplied.
+    Trim scans from the edges and eliminates rows / cols which only
+    contain the values supplied.
 
-    Parameters:
+    Parameters
     ----------
-    raster: xarray.DataArray
-    values: list, tuple (default = (np.nan))
-        list of zone ids to trim from raster edge
-    name: str (default = 'trim')
-        output xr.DataArray.name property
+    raster: xr.DataArray
+    values: list or tuple, default=(np.nan)
+        List of zone ids to trim from raster edge.
+    name: str, default='trim'
+        Output xr.DataArray.name property.
 
-    Returns:
-    ----------
-    xarray.DataArray
+    Returns
+    -------
+    trim_agg : xarray.DataArray
 
-    Notes:
-    ----------
-    This operation will change the output size of the raster
+    Notes
+    -----
+        - This operation will change the output size of the raster.
+
+    Examples
+    --------
+    .. plot::
+       :include-source:
+
+        import datashader as ds
+        import numpy as np
+        import matplotlib.pyplot as plt
+        from xrspatial import generate_terrain
+        from xrspatial.zonal import trim
+
+        # Create Canvas
+        W = 500
+        H = 300
+        cvs = ds.Canvas(plot_width = W,
+                        plot_height = H,
+                        x_range = (-20e6, 20e6),
+                        y_range = (-20e6, 20e6))
+
+
+        # Generate Terrain
+        terrain_agg = generate_terrain(canvas = cvs)
+
+        # Edit Attributes
+        terrain_agg = terrain_agg.assign_attrs(
+            {
+                'Description': 'Example Terrain',
+                'units': 'km',
+                'Max Elevation': '4000',
+            }
+        )
+
+        terrain_agg = terrain_agg.rename({'x': 'lon', 'y': 'lat'})
+        terrain_agg = terrain_agg.rename('Elevation')
+        terrain_agg = terrain_agg.astype('int')
+
+        # Trim Image
+        trimmed_agg = trim(raster = terrain_agg, values = [0])
+
+        # Edit Attributes
+        trimmed_agg = trimmed_agg.assign_attrs({'Description': 'Example Trim'})
+
+        # Plot Terrain
+        terrain_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Terrain")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+        # Plot Trimmed Terrain
+        trimmed_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Trim")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+    .. sourcecode:: python
+
+        >>> print(terrain_agg.shape)
+        (300, 500)
+
+        >>> print(terrain_agg.attrs)
+        {
+            'res': 1,
+            'Description': 'Example Terrain',
+            'units': 'km',
+            'Max Elevation': '4000',
+        }
+
+        >>> print(trimmed_agg.shape)
+        (268, 500)
+
+        >>> print(trimmed_agg.attrs)
+        {
+            'res': 1,
+            'Description': 'Example Trim',
+            'units': 'km',
+            'Max Elevation': '4000',
+        }
     """
-
     top, bottom, left, right = _trim(raster.data, values)
     arr = raster[top:bottom+1, left:right+1]
     arr.name = name
@@ -862,32 +1200,112 @@ def crop(zones: xr.DataArray,
          zones_ids: Union[list, tuple],
          name: str = 'crop'):
     """
-    Crop scans from edges and eliminates rows / cols
-    until one of the input values is found.
+    Crop scans from edges and eliminates rows / cols until one of the
+    input values is found.
 
-    Parameters:
+    Parameters
     ----------
-    zones : xarray.DataArray
-        input zone raster
+    zones : xr.DataArray
+        Input zone raster.
 
-    values: xarray.DataArray
-        input values raster
+    values: xr.DataArray
+        Input values raster.
 
-    zones_ids : list, tuple
-        list of zone ids to crop raster
+    zones_ids : list or tuple
+        List of zone ids to crop raster.
 
-    name: str (default = 'crop')
-        output xr.DataArray.name property
+    name: str, default='crop'
+        Output xr.DataArray.name property.
 
-    Returns:
-    ----------
-    xarray.DataArray
+    Returns
+    -------
+    crop_agg : xarray.DataArray
 
-    Notes:
-    ----------
-    This operation will change the output size of the raster
+    Notes
+    -----
+        - This operation will change the output size of the raster.
+
+    Examples
+    --------
+    .. plot::
+       :include-source:
+
+        import datashader as ds
+        import matplotlib.pyplot as plt
+        from xrspatial import generate_terrain
+        from xrspatial.zonal import crop
+
+        # Create Canvas
+        W = 500
+        H = 300
+        cvs = ds.Canvas(plot_width = W,
+                        plot_height = H,
+                        x_range = (-20e6, 20e6),
+                        y_range = (-20e6, 20e6))
+
+
+        # Generate Zones
+        terrain_agg = generate_terrain(canvas = cvs)
+
+        # Edit Attributes
+        terrain_agg = terrain_agg.assign_attrs(
+            {
+                'Description': 'Example Terrain',
+                'units': 'km',
+                'Max Elevation': '4000',
+            }
+        )
+
+        terrain_agg = terrain_agg.rename({'x': 'lon', 'y': 'lat'})
+        terrain_agg = terrain_agg.rename('Elevation')
+
+        # Crop Image
+        values_agg = terrain_agg[0:300, 0:250]
+        cropped_agg = crop(
+            zones=terrain_agg,
+            values=values_agg,
+            zones_ids=[0],
+        )
+
+        # Edit Attributes
+        cropped_agg = cropped_agg.assign_attrs({'Description': 'Example Crop'})
+
+        # Plot Terrain
+        terrain_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Terrain")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+        # Plot Cropped Terrain
+        cropped_agg.plot(cmap = 'terrain', aspect = 2, size = 4)
+        plt.title("Crop")
+        plt.ylabel("latitude")
+        plt.xlabel("longitude")
+
+    .. sourcecode:: python
+
+        >>> print(terrain_agg.shape)
+        (300, 500)
+
+        >>> print(terrain_agg.attrs)
+        {
+            'res': 1,
+            'Description': 'Example Terrain',
+            'units': 'km',
+            'Max Elevation': '4000',
+        }
+
+        >>> print(cropped_agg.shape)
+        (300, 250)
+
+        >>> print(cropped_agg.attrs)
+        {
+            'res': 1,
+            'Description': 'Example Crop',
+            'units': 'km',
+            'Max Elevation': '4000',
+        }
     """
-
     top, bottom, left, right = _crop(zones.data, zones_ids)
     arr = values[top:bottom+1, left:right+1]
     arr.name = name
